#!/bin/bash

set -e

function help {
	echo "USAGE:"
	echo -e "\t$0 flash\t-- flash system.img and userdata.img"
	echo -e "\t$0 boot \t-- boot system using boot.img"
	echo -e "\t$0 pm_stats\t-- record power stats to ~/pm_stats/\$2"
}

function flash {
	if [ ! -e system.img ] || [ ! -e userdata.img ]; then
		echo "ERR -- Must be run in product out directory"
		exit 1
	fi

	fastboot flash system system.img
	sleep 2s
	fastboot flash userdata userdata.img
	sleep 2s
}

function boot {
	if [ ! -e boot.img ]; then
		echo "ERR -- Must be run in product out directory"
		exit 1
	fi

	fastboot boot boot.img
}

function dump {
	echo "! S DUMP $1 `cat /proc/uptime`" | tee -a $FILE
	echo "cat /proc/msm_pm_stats > data/pm_stats.txt; exit" | adb shell
	rm -f $PULLFILE; adb pull data/pm_stats.txt $PULLFILE > /dev/null
	cat $PULLFILE >> $FILE
	echo "! E DUMP $1 `cat /proc/uptime`" | tee -a $FILE
}

function pm_stats {
	FILE=`tempfile`
	PULLFILE=`tempfile`

	echo -e "Writing to $FILE\n"
	echo "# START" | tee -a $FILE
	echo "! S FLASH `cat /proc/uptime`" | tee -a $FILE
	flash
	echo "! E FLASH `cat /proc/uptime`" | tee -a $FILE
	echo "! S BOOT `cat /proc/uptime`" | tee -a $FILE
	boot
	echo "! E BOOT `cat /proc/uptime`" | tee -a $FILE
	sleep 15s; dump 15
	sleep 15s; dump 30
	sleep 30s; dump 60
	sleep 60s; dump 120
	sleep 60s; dump 180
	sleep 60s; dump 240

	rm $PULLFILE
	echo -e "\n\tResults in $FILE\n"
	if [ -n "${1}" ]; then
		DEST="$1_$[`ls ~/pm_stats/$1_* | cut -d"_" -f3 | sort | tail -n 1` + 1]"
		echo $FILE move to $DEST
		mv -v -n $FILE ~/pm_stats/$DEST
	fi
}

if [ -n "${1}" ]; then
	$1 $2
else
	help
fi
